/* alf.h
 * 
 * Copyright (C) 2009 Patrick Alken
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __ALF_H__
#define __ALF_H__

typedef enum
{
  ALF_NORM_NONE,
  ALF_NORM_SPHARM,
  ALF_NORM_ORTHO,
  ALF_NORM_SCHMIDT
} alf_norm_t;

typedef struct
{
  int lmax;        /* maximum degree of associated legendre polynomials */
  double *sqrts;   /* array holding square roots of integer values */

  /*
   * This array contains coefficients to convert S(l,m) to other
   * normalizations
   *
   * {Y,N}(l,m)(x) = alpha(l) * S(l,m)
   */
  double *alpha;

  double csphase;  /* Condon-Shortley phase (-1)^m */
  int cnorm;       /* apply complex normalization */
  alf_norm_t norm; /* normalization type */
} alf_workspace;

#define ALF_CSPHASE_DEFAULT     1
#define ALF_CNORM_DEFAULT       0
#define ALF_NORM_DEFAULT        ALF_NORM_SCHMIDT

/*
 * Prototypes
 */

alf_workspace *alf_alloc(const int lmax);
void alf_free(alf_workspace *w);
int alf_params(int csphase, int cnorm, alf_norm_t norm, alf_workspace *w);
int alf_Plm_array(const int degree, const double x, double result_array[],
                  alf_workspace *w);
int alf_Plm_deriv_array(const int degree, const double x,
                        double result_array[], double result_deriv_array[],
                        alf_workspace *w);
int alf_Plm_deriv2_array(const int degree, const double x,
                         double result_array[], double result_deriv_array[],
                         double result_deriv2_array[],
                         alf_workspace *w);
size_t alf_array_size(const int lmax);
size_t alf_array_index(const int l, const int m);

#endif /* __ALF_H__ */
